
OpenPLC Desktop
=========================================

This is a desktop app (pyqthon3/PyQt5) to run alongside the
new `openplc-server <https://gitlab.com/openplcproject/openplc_go/>`_ and REST api written in go

**This project is still at alpha stage**

Install
------------

From PyPi https://pypi.org/project/openplc-desktop/

.. code-block:: console

    pip3 install openplc-desktop
    openplc-desktop.py


.. code-block:: console

    # clone with http
    git clone https://gitlab.com/openplcproject/openplc_desktop.git

    # or git
    git clone git@gitlab.com:openplcproject/openplc_desktop.git

    # then run
    cd openplc_desktop
    ./openplc-desktop.py

